Documentation
¶
Index ¶
Constants ¶
const (
TLSTimeOut = 30 * time.Second
)
Variables ¶
This section is empty.
Functions ¶
func BuildHostAgentClientConfig ¶
func BuildHostAgentClientConfig(ctx context.Context, opt *options.HostAgentFlags) (*restclient.Config, certificate.Manager, error)
func GetConfigOrDie ¶
func GetConfigOrDie(opt *options.HostAgentFlags) *restclient.Config
GetConfigOrDie returns a config for client. It will try to use the in-cluster config first, and if that fails, it will try to use the kubeconfig and bootstrap files.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.