Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CheckovCheckResult ¶
type CheckovConfig ¶
type CheckovConfig struct {
// Exclusions are checkov failures which should not lead to a failure.
Exclusions map[string]CheckovExclusions `json:"exclusions"`
}
CheckovConfig represents the configuration for this tool to define exclusions.
type CheckovExclusion ¶
type CheckovExclusion struct {
CheckovFailure
// contains filtered or unexported fields
}
CheckovExclusion is a exclusion for a checkov finding with a found bool to help tracking if the exclusion has been found during analyzation.
type CheckovExclusions ¶
type CheckovExclusions []*CheckovExclusion
CheckovExclusions is a list of exclusions for checkov reports.
type CheckovFailedCheck ¶
type CheckovFailure ¶
type CheckovFailure struct {
CheckID string `json:"check_id"`
Resource string `json:"resource"`
EvaluatedKeys []string `json:"evaluated_keys"`
// contains filtered or unexported fields
}
CheckovFailure is the data struct used in the reports created by running checkov.
func (CheckovFailure) String ¶
func (c CheckovFailure) String() string
type CheckovReport ¶
type CheckovReport struct {
Results CheckovResults `json:"results"`
}
type CheckovResults ¶
type CheckovResults struct {
FailedChecks []CheckovFailedCheck `json:"failed_checks"`
}
type JUnitTestSuites ¶
type JUnitTestSuites struct {
XMLName xml.Name `xml:"testsuites"`
TestSuites []report.JUnitTestSuite `xml:"testsuite"`
}
JUnitTestSuites represents the root element of the JUnit XML
Click to show internal directories.
Click to hide internal directories.