predicates

package
v0.1.0-latest-stable Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 30, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConditionChanged

func ConditionChanged(conditionType conditions.ConditionType) predicate.Funcs

ConditionChanged returns a predicate that triggers only when the status of the given condition type changes. This is useful for filtering out status updates that don't affect the condition being watched. The object must implement conditions.GetSet interface.

func PredicateFuncsByEventTypes

func PredicateFuncsByEventTypes(events ...any) predicate.Funcs

PredicateFuncsByEventTypes returns a predicate that returns true for the provided event types

func ReadyConditionChanged

func ReadyConditionChanged() predicate.Funcs

ReadyConditionChanged returns a predicate that triggers only on Ready condition changes. This is useful for filtering out status updates that don't affect the Ready state. The object must implement conditions.GetSet interface.

func TypedResourceIsChanged

func TypedResourceIsChanged[T client.Object]() predicate.TypedFuncs[T]

TypedResourceIsChanged returns a predicate that returns true only if the resource has changed. This predicate allows to drop resync events on additionally watched objects.

Types

This section is empty.

Jump to